/*
 * 	data.c - Data structure functions
 *
 * 	This file is part of libglacier.
 *
 * 	Liblacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Libglacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License along with Libglacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

#include "common.h"
#include "../include/log.h"

/* ALL FUNCTIONS IN THIS FILE DEFINED IN: data.h */

/*
 * node
 *
 * DESCRIPTION: Definition of node type.
 * DEFINED IN: data.h
 *
 */

struct node {
	char *data;
	struct node *children[MAX_CHILDREN];
	int numChildren;
};

struct node
*create_node(char *data)
{
	struct node *newNode = (struct node*)malloc(sizeof(struct node));
	newNode->data 	     = strdup(data);
	newNode->numChildren = 0;
	return newNode;
}

/*
 * add_child
 *
 * DESCRIPTION: Add a child node to a parent node.
 * PARAMETERS: struct node *parent, struct node *child
 * DEFINED IN: data.h
 *
 */

void
add_child(struct node *parent, struct node *child)
{
	if (parent->numChildren < MAX_CHILDREN) {
		parent->children[parent->numChildren++] = child;
	} else {
		if (LG_VERBOSE == 1) { errlog("Maximum number of children exceeded"); }
		exit(1);
	}
}

/*
* print_tree
*
* DESCRIPTION: Print a dependency tree.
* PARAMETERS: struct node *root, int level
* DEFINED IN: data.h
*
*/

void
print_tree(struct node *root, int level)
{
	if (root == NULL) {
		return;
	}

	for (int i = 0; i < level; i++) {
		printf("	");
	}

	printf("%s\n", root->data);

	for (int i = 0; i < root->numChildren; i++) {
		print_tree(root->children[i], level + 1);
	}
}
