/*
 * 	data.c - Data structure functions
 *
 * 	This file is part of libglacier.
 *
 * 	Liblacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Libglacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License along with Libglacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

#include "common.h"

/* ALL FUNCTIONS IN THIS FILE DEFINED IN: log.h */

/*
 * infolog
 *
 * DESCRIPTION: Output a stylized info message.
 * PARAMETERS: char MSG[]
 * DEFINED IN: log.h
 *
 */

void
infolog(char MSG[])
{
	if (MSG == NULL) {
		return;
	}

	printf(COL_BLUE "[i]" COL_RESET " %s\n", MSG);
	return;
}

/*
 * warnlog
 *
 * DESCRIPTION: Output a stylized warning message.
 * Parameters: char MSG[]
 * DEFINED IN: log.h
 *
 */

void
warnlog(char MSG[])
{
	if (MSG == NULL) {
		return;
	}

	printf(COL_YELLOW "[!]" COL_RESET " %s\n", MSG);
	return;
}

/*
 * errlog
 * 
 * DESCRIPTION: Output a stylized error message.
 * PARAMETERS: char MSG[]
 * DEFINED IN: log.h
 *
 */

void
errlog(char MSG[])
{
	if (MSG == NULL) {
		return;
	}

	fprintf(stderr, COL_RED "[x]" COL_RESET " %s\n", MSG);
	return;
}

/*
 * successlog
 * 
 * DESCRIPTION: Output a stylized success message.
 * PARAMETERS: char MSG[]
 * DEFINED IN: log.h
 *
 */

void
successlog(char MSG[])
{
	if (MSG == NULL) {
		return;
	}

	printf(COL_GREEN "[*]" COL_RESET " %s\n", MSG);
	return;
}


