/*
 * 	runtime.c - Runtime functions
 *
 * 	This file is part of libglacier.
 *
 * 	Liblacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Libglacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License along with Libglacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

#include "common.h"

/* ALL FUNCTIONS IN THIS FILE DEFINED IN: runtime.h */

/*
 * runtime_exists
 *
 * DESCRIPTION: Check if necesary runtime files exist.
 * PARAMETERS: None.
 * DEFINED IN: runtime.h
 *
 */

int
runtime_exists(void)
{
	int f;

	for (f = 0; f < sizeof(runtime_files); f++) {
		if (access(runtime_files[f], F_OK) == 0) {
			continue;
		} else {
			/* might keep this message, might not, idk */
			/* errlog("Runtime files are missing, cannot continue with operation.");
			printf(COL_RED "[x]" COL_RESET " The following files are missing:\n");
			printf(COL_RED "[x]" COL_RESET " \t%s\n", runtime_files[f]); */
			return 0;
		}
	}
	return 1;
}

/*
 * is_process_root
 *
 * DESCRIPTION: Check if process is running as root.
 * PARAMETERS: char MSG[]
 * DEFINED IN: runtime.h
 *
 */

int
is_process_root(void)
{
	if (getuid() != 0) {
		return 0; /* process is not running as root */
	}
	else {
		return 1; /* process is running as root */
	}
}

